@@ -1,6 +1,8 @@
+
 import os
 
 from . import analysis
+from . import geometry
 
 from .analysis import *
 from .geometry import *
@@ -12,12 +14,13 @@ from .version import __version__
 # Contents
 __all__ = [
     'analysis',
-    'geometry',
     'io',
     'include_dir',
     'misc',
     '__version__'
 ]
 
+__all__.extend(geometry.__all__)
+
 # Add include path
 include_dir = os.path.abspath(__file__ + '/../../include')
